# Put in a separate page so it can be used by SciMLDocs.jl

pages = [
    "Home" => "index.md",
    "AbstractVectorOfArrayInterface.md",
    "array_types.md",
    "recursive_array_functions.md",
]
